@@ -16,6 +16,7 @@ from falocalrepo_database import FADatabase
 from falocalrepo_database import FADatabaseCursor
 from falocalrepo_database import FADatabaseTable
 from falocalrepo_database import __version__ as __database_version__
+from falocalrepo_database.database import clean_username
 from falocalrepo_server import __version__ as __server_version__
 from falocalrepo_server import server
 from psutil import AccessDenied
@@ -26,10 +27,10 @@ from .__version__ import __version__
 from .commands import latest_version
 from .commands import make_journal
 from .commands import make_submission
+from .commands import make_user
 from .commands import print_items
 from .commands import print_users
 from .commands import search
-from .download import clean_username
 from .download import download_journals as download_journals_
 from .download import download_submissions as download_submissions_
 from .download import download_users as download_users_
@@ -311,11 +312,7 @@ def download_users(db: FADatabase, *args: str):
     if len(args) != 2:
         raise MalformedCommand("users needs two arguments")
 
-    users_tmp: list[str] = list(filter(bool, map(clean_username, args[0].split(","))))
-    users: list[str] = sorted(set(users_tmp), key=users_tmp.index)
-    folders_tmp: list[str] = list(filter(bool, map(str.strip, args[1].split(","))))
-    folders: list[str] = sorted(set(folders_tmp), key=folders_tmp.index)
-    download_users_(db, users, folders)
+    download_users_(db, args[0].split(","), args[1].split(","))
 
 
 def download_update(db: FADatabase, *args: str):
@@ -350,15 +347,9 @@ def download_update(db: FADatabase, *args: str):
         falocalrepo download update tom,jerry
     """
 
-    users: list[str] = []
-    folders: list[str] = []
+    users: list[str] = args[0].split(",") if args and args[0] != "@" else []
+    folders: list[str] = args[1].split(",") if args[1:] and args[1] != "@" else []
     opts, args = parse_args(args)
-    if args and args[0] != "@":
-        users_tmp: list[str] = list(filter(bool, map(clean_username, args[0].split(","))))
-        users = sorted(set(users_tmp), key=users_tmp.index)
-    if args[1:] and args[1] != "@":
-        folders_tmp: list[str] = list(filter(bool, map(str.strip, args[1].split(","))))
-        folders = sorted(set(folders_tmp), key=folders_tmp.index)
     download_users_update(db, users, folders, int(opts.get("stop", 1)), opts.get("deactivated", "").lower() == "true")
 
 
@@ -568,16 +559,8 @@ def database_add_user(db: FADatabase, *args):
         falocalrepo database add-user ./user.json
     """
 
-    make_params: dict[str, str] = parameters(args)
-    username: str = db.users.new_user(make_params["username"])
-    if make_params.get("folders", None) is not None:
-        folders: set[str] = set(db.users[username]["FOLDERS"])
-        folders_new: set[str] = set(filter(bool, map(str.lower, make_params["folders"].split(","))))
-        for f in folders - folders_new:
-            db.users.remove_user_folder(username, f)
-        for f in folders_new - folders:
-            db.users.add_user_folder(username, f)
-    db.commit()
+    data: dict = load(open(args[0]))
+    make_user(db, data)
 
 
 def database_add_submission(db: FADatabase, *args: str):
@@ -731,9 +714,9 @@ def database_server(db: FADatabase, *args: str):
         falocalrepo database server host=127.0.0.1 port=5000
     """
 
+    db.close()
     opts, _ = parse_args(args)
-    server(db.database_path, **opts)
-    print()
+    server(db.database_path, host=opts.get("host", "0.0.0.0"), port=int(opts.get("port", 8080)))
 
 
 def database_merge_copy(db: FADatabase, merge: bool = True, *args):
@@ -1003,6 +986,6 @@ def console(comm: str = "", *args: str) -> None:
         elif comm == database.__name__:
             database(db, *args)
     finally:
-        if db is not None:
+        if db is not None and db.is_open():
             db.commit()
             db.close()
